Module avro_data_model_to_serde

Module avro_data_model_to_serde 

Mapping the Avro data model to the Serde data model

When manually mapping an Avro schema to Rust types it is important to understand how the different data models are mapped. When mapping from Rust types to an Avro schema, see the documentation for the reverse.

Only the mapping as defined here is supported. Any other behavior might change in a minor version.

Primitive Types

Complex Types