RabinFingerprintHeader

Struct RabinFingerprintHeader 

pub struct RabinFingerprintHeader { /* private fields */ }
HeaderBuilder based on the Rabin schema fingerprint.

This is the default and will be used automatically by the new impls in GenericSingleObjectReader and GenericSingleObjectWriter.

Implementations

Source

impl RabinFingerprintHeader

pub fn from_schema(schema: &Schema) -> Self

Use this helper to build an instance from an existing Avro Schema.