ReaderBuilder

Struct ReaderBuilder 

pub struct ReaderBuilder<'a, R: Read, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'a, R: Read, S: State> ReaderBuilder<'a, R, S>

pub fn build(self) -> AvroResult<Reader<'a, R>>
where S: IsComplete,

Finishes building and performs the requested action.

pub fn reader_schema( self, value: &'a Schema, ) -> ReaderBuilder<'a, R, SetReaderSchema<S>>
where S::ReaderSchema: IsUnset,

Optional (Some / Option setters). The schema the written data needs to be adapted to.

This is currently not compatible with ReaderDeser and will panic during reading if the writer schema is not the same as the reader schema.

pub fn maybe_reader_schema( self, value: Option<&'a Schema>, ) -> ReaderBuilder<'a, R, SetReaderSchema<S>>
where S::ReaderSchema: IsUnset,

Optional (Some / Option setters). The schema the written data needs to be adapted to.

This is currently not compatible with ReaderDeser and will panic during reading if the writer schema is not the same as the reader schema.

pub fn schemata( self, value: Vec<&'a Schema>, ) -> ReaderBuilder<'a, R, SetSchemata<S>>
where S::Schemata: IsUnset,

Optional (Some / Option setters).

pub fn maybe_schemata( self, value: Option<Vec<&'a Schema>>, ) -> ReaderBuilder<'a, R, SetSchemata<S>>
where S::Schemata: IsUnset,

Optional (Some / Option setters).

pub fn human_readable( self, value: bool, ) -> ReaderBuilder<'a, R, SetHumanReadable<S>>
where S::HumanReadable: IsUnset,

Optional (Some / Option setters). Default: is_human_readable().

pub fn maybe_human_readable( self, value: Option<bool>, ) -> ReaderBuilder<'a, R, SetHumanReadable<S>>
where S::HumanReadable: IsUnset,

Optional (Some / Option setters). Default: is_human_readable().