pub struct Alias(/* private fields */);Expand description
Newtype pattern for Name to better control the serde_json::Value representation.
Aliases are serialized as an array of plain strings in the JSON representation.
Implementations
Sourceimpl Alias
impl Alias
pub fn new(name: &str) -> AvroResult<Self>
pub fn name(&self) -> &str
pub fn namespace(&self) -> NamespaceRef<'_>
pub fn fullname(&self, enclosing_namespace: NamespaceRef<'_>) -> String
pub fn fully_qualified_name( &self, default_namespace: NamespaceRef<'_>, ) -> Cow<'_, Name>