StructFieldEq

Struct StructFieldEq 

pub struct StructFieldEq {
    pub include_attributes: bool,
}
Compares [the canonical forms] of two schemas for equality field by field.

This means that attributes like aliases, doc, default and logicalType are ignored.

the canonical forms

Fields

include_attributes: bool

Whether to include custom attributes in the comparison.

The custom attributes are not used to construct the canonical form of the schema!