pub fn set_enum_symbol_name_validator(
validator: Box<dyn EnumSymbolNameValidator + Send + Sync>,
) -> Result<(), Box<dyn EnumSymbolNameValidator + Send + Sync>>Expand description
Sets a custom enum symbol name validator.
Returns Err(validator) if a validator is already configured.
Note: This function must be called before parsing any schema because this will register the default validator and the registration is one time only!