pub fn set_schema_name_validator(
validator: Box<dyn SchemaNameValidator + Send + Sync>,
) -> Result<(), Box<dyn SchemaNameValidator + Send + Sync>>Expand description
Sets a custom schema name validator.
Returns Err(validator) if a validator is already configured.
Note: This function must be called before parsing any schema because this will register the default validator and the registration is one time only!