pub fn set_schema_namespace_validator(
validator: Box<dyn SchemaNamespaceValidator + Send + Sync>,
) -> Result<(), Box<dyn SchemaNamespaceValidator + Send + Sync>>Expand description
Sets a custom schema namespace validator.
Returns Err(validator) if a validator is already configured.
Note: This function must be called before parsing any schema because this will register the default validator and the registration is one time only!