pub fn to_avro_datum_schemata<T: Into<Value>>(
schema: &Schema,
schemata: Vec<&Schema>,
value: T,
) -> AvroResult<Vec<u8>>Expand description
Encode a value into raw Avro data, also performs schema validation.
If the provided schema is incomplete then its dependencies must be
provided in schemata