Module apache_avro::schema
source · [−]Expand description
Logic for parsing and interacting with schemas in Avro format.
Structs
Newtype pattern for Name to better control the serde_json::Value representation.
Aliases are serialized as an array of plain strings in the JSON representation.
Represents names for record, enum and fixed Avro schemas.
Represents a field in a record Avro schema.
Represents an Avro schema fingerprint More information about Avro schema fingerprints can be found in the Avro Schema Fingerprint documentation
Enums
Represents any valid order for a field in a record Avro schema.
Represents any valid Avro schema More information about Avro schemas can be found in the Avro Specification
Auto-generated discriminant enum variants
Traits
Trait for types that serve as an Avro data model. Derive implementation available
through derive feature. Do not implement directly!
Implement apache_avro::schema::derive::AvroSchemaComponent to get this trait
through a blanket implementation.
Type Definitions
Represents the aliases for Named Schema
Represents documentation for complex Avro schemas.
Represents the namespace for Named Schema