Enum apache_avro::types::Value
source · [−]pub enum Value {
Show 22 variants
Null,
Boolean(bool),
Int(i32),
Long(i64),
Float(f32),
Double(f64),
Bytes(Vec<u8>),
String(String),
Fixed(usize, Vec<u8>),
Enum(u32, String),
Union(u32, Box<Value>),
Array(Vec<Value>),
Map(HashMap<String, Value>),
Record(Vec<(String, Value)>),
Date(i32),
Decimal(Decimal),
TimeMillis(i32),
TimeMicros(i64),
TimestampMillis(i64),
TimestampMicros(i64),
Duration(Duration),
Uuid(Uuid),
}Expand description
A valid Avro value.
More information about Avro values can be found in the Avro Specification
Variants
Null
A null Avro value.
Boolean(bool)
A boolean Avro value.
Int(i32)
A int Avro value.
Long(i64)
A long Avro value.
Float(f32)
A float Avro value.
Double(f64)
A double Avro value.
Bytes(Vec<u8>)
A bytes Avro value.
String(String)
A string Avro value.
Fixed(usize, Vec<u8>)
A fixed Avro value.
The size of the fixed value is represented as a usize.
Enum(u32, String)
An enum Avro value.
An Enum is represented by a symbol and its position in the symbols list of its corresponding schema. This allows schema-less encoding, as well as schema resolution while reading values.
Union(u32, Box<Value>)
An union Avro value.
A Union is represented by the value it holds and its position in the type list of its corresponding schema This allows schema-less encoding, as well as schema resolution while reading values.
Array(Vec<Value>)
An array Avro value.
Map(HashMap<String, Value>)
A map Avro value.
Record(Vec<(String, Value)>)
A record Avro value.
A Record is represented by a vector of (<record name>, value).
This allows schema-less encoding.
See Record for a more user-friendly support.
Date(i32)
A date value.
Serialized and deserialized as i32 directly. Can only be deserialized properly with a
schema.
Decimal(Decimal)
An Avro Decimal value. Bytes are in big-endian order, per the Avro spec.
TimeMillis(i32)
Time in milliseconds.
TimeMicros(i64)
Time in microseconds.
TimestampMillis(i64)
Timestamp in milliseconds.
TimestampMicros(i64)
Timestamp in microseconds.
Duration(Duration)
Avro Duration. An amount of time defined by months, days and milliseconds.
Uuid(Uuid)
Universally unique identifier.
Implementations
sourceimpl Value
impl Value
sourcepub fn validate(&self, schema: &Schema) -> bool
pub fn validate(&self, schema: &Schema) -> bool
Validate the value against the given Schema.
See the Avro specification for the full set of rules of schema validation.
sourcepub fn resolve(self, schema: &Schema) -> AvroResult<Self>
pub fn resolve(self, schema: &Schema) -> AvroResult<Self>
Attempt to perform schema resolution on the value, with the given Schema.
See Schema Resolution in the Avro specification for the full set of rules of schema resolution.