Enum apache_avro::types::ValueKind
source · [−]pub enum ValueKind {
Show 22 variants
Null,
Boolean,
Int,
Long,
Float,
Double,
Bytes,
String,
Fixed,
Enum,
Union,
Array,
Map,
Record,
Date,
Decimal,
TimeMillis,
TimeMicros,
TimestampMillis,
TimestampMicros,
Duration,
Uuid,
}Expand description
Auto-generated discriminant enum variants
Variants
Null
A null Avro value.
Boolean
A boolean Avro value.
Int
A int Avro value.
Long
A long Avro value.
Float
A float Avro value.
Double
A double Avro value.
Bytes
A bytes Avro value.
String
A string Avro value.
Fixed
A fixed Avro value.
The size of the fixed value is represented as a usize.
Enum
An enum Avro value.
An Enum is represented by a symbol and its position in the symbols list of its corresponding schema. This allows schema-less encoding, as well as schema resolution while reading values.
Union
An union Avro value.
A Union is represented by the value it holds and its position in the type list of its corresponding schema This allows schema-less encoding, as well as schema resolution while reading values.
Array
An array Avro value.
Map
A map Avro value.
Record
A record Avro value.
A Record is represented by a vector of (<record name>, value).
This allows schema-less encoding.
See Record for a more user-friendly support.
Date
A date value.
Serialized and deserialized as i32 directly. Can only be deserialized properly with a
schema.
Decimal
An Avro Decimal value. Bytes are in big-endian order, per the Avro spec.
TimeMillis
Time in milliseconds.
TimeMicros
Time in microseconds.
TimestampMillis
Timestamp in milliseconds.
TimestampMicros
Timestamp in microseconds.
Duration
Avro Duration. An amount of time defined by months, days and milliseconds.
Uuid
Universally unique identifier.