GenericDatumWriterBuilder

Struct GenericDatumWriterBuilder 

pub struct GenericDatumWriterBuilder<'s, S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<'s, S: State> GenericDatumWriterBuilder<'s, S>

pub fn build(self) -> AvroResult<GenericDatumWriter<'s>>
where S: IsComplete,

Finishes building and performs the requested action.

pub fn resolved_schemata( self, value: ResolvedSchema<'s>, ) -> GenericDatumWriterBuilder<'s, SetResolvedSchemata<S>>
where S::ResolvedSchemata: IsUnset,

Optional (Some / Option setters). Already resolved schemata that will be used to resolve references in the writer’s schema.

You can also use Self::schemata instead.

pub fn maybe_resolved_schemata( self, value: Option<ResolvedSchema<'s>>, ) -> GenericDatumWriterBuilder<'s, SetResolvedSchemata<S>>
where S::ResolvedSchemata: IsUnset,

Optional (Some / Option setters). Already resolved schemata that will be used to resolve references in the writer’s schema.

You can also use Self::schemata instead.

pub fn validate( self, value: bool, ) -> GenericDatumWriterBuilder<'s, SetValidate<S>>
where S::Validate: IsUnset,

Optional (Some / Option setters). Default: true.

Validate values against the writer schema before writing them.

Defaults to true.

Setting this to false and writing values that don’t match the schema will make the written data unreadable.

pub fn maybe_validate( self, value: Option<bool>, ) -> GenericDatumWriterBuilder<'s, SetValidate<S>>
where S::Validate: IsUnset,

Optional (Some / Option setters). Default: true.

Validate values against the writer schema before writing them.

Defaults to true.

Setting this to false and writing values that don’t match the schema will make the written data unreadable.

Source

impl<'s, S: State> GenericDatumWriterBuilder<'s, S>

pub fn schemata( self, schemata: Vec<&'s Schema>, ) -> AvroResult<GenericDatumWriterBuilder<'s, SetResolvedSchemata<S>>>
where S::ResolvedSchemata: IsUnset,

Set the schemata that will be used to resolve any references in the schema.

This is equivalent to .resolved_schemata(ResolvedSchema::new_with_schemata(schemata)?). If you already have a ResolvedSchema, use that function instead.